# PyLoss

```shell
.
├── LICENSE
├── pyloss
│  ├── __init__.py
│  ├── pixel_based
│  │  ├── __init__.py
│  │  ├── cross_entropy.py
│  │  ├── mae_mse.py
│  │  └── total_variation.py
│  ├── region_based
│  │  ├── __init__.py
│  │  ├── dice_iou.py
│  │  ├── hel.py
│  │  └── ssim.py
│  └── utils
│     ├── __init__.py
│     ├── convert_onehot.py
│     └── misc.py
├── pyproject.toml
└── README.md
```

Some loss functions for deeplearning.
